import { Textbus } from "@textbus/core";
import { MappingItem, Suggest } from "./suggest";
import { parseFetchRes2FieldMapping } from "./utils/index";
import './styles/index.scss';
type HTMLTarget = HTMLElement | (() => HTMLElement);
type MEditorConfig = {
    /**
     * 要挂载到的元素，可以是HTMLElement，也可以是一个函数，返回一个HTMLElement
     */
    target: HTMLTarget;
    /**
     * 是否开启debug模式
     */
    debug?: boolean;
    /**
     * 搜索建议的配置项
     */
    suggest: Suggest;
    /**
     * 编辑器回车时的回调
     * @param value 编辑框的内容
     * @returns
     */
    onSubmit: (value: string) => void;
};
export type MEditor = {
    /**
     * 编辑器实例
     */
    editor: Textbus;
    /**
     * 插入指定内容，会自动判断空格和处理类型等。。
     */
    choose: (item: MappingItem) => void;
    /**
     * 设置当前编辑器的内容
     * @todo 自动解析格式信息
     * @param str
     * @returns
     */
    setValue: (str: string) => void;
    /**
     * 获取当前编辑器的内容
     * @returns
     */
    getValue: () => string;
};
export declare function createMEditor(config: MEditorConfig): Promise<MEditor>;
export { parseFetchRes2FieldMapping };
export type { MappingItem, SuggestConfig } from "./suggest";
export { MappingFieldType, Suggest } from "./suggest";
